=== modified file 'about.py'
--- about.py	2008-06-28 17:13:46 +0000
+++ about.py	2008-04-01 09:59:41 +0000
@@ -25,23 +25,13 @@
 import os
 from bzrlib.plugins.gtk import icon_path
 
-
-def read_license():
-    license_file = os.path.join(os.path.dirname(__file__), "COPYING")
-    if os.path.exists(license_file):
-        return file(license_file).read()
-    # Fall back to just license name if we can't find the file
-    return "GPLv2 or later"
-
-
 class AboutDialog(gtk.AboutDialog):
     def __init__(self):
         super(AboutDialog, self).__init__()
         self.set_name("Bazaar GTK")
         self.set_version(bzrlib.plugins.gtk.version_string)
         self.set_website("http://bazaar-vcs.org/BzrGtk")
-        self.set_license(read_license())
-        self.set_logo(gtk.gdk.pixbuf_new_from_file(icon_path("bzr-icon-64.png")))
+        self.set_license("GNU GPL v2 or later")
+        self.set_icon(gtk.gdk.pixbuf_new_from_file(icon_path("bzr-icon-64.png")))
         self.connect ("response", lambda d, r: d.destroy())
 
-

=== modified file 'branchview/linegraph.py'
--- branchview/linegraph.py	2008-05-04 18:16:01 +0000
+++ branchview/linegraph.py	2008-06-29 15:54:40 +0000
@@ -12,8 +12,8 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.tsort import merge_sort
 
-def linegraph(repository, start_revs, maxnum, broken_line_length = None,
-              graph_data = True, mainline_only = False):
+def linegraph(graph, start_revs, maxnum=None, broken_line_length=None,
+              graph_data=True, mainline_only=False):
     """Produce a directed graph of a bzr repository.
 
     Returns a tuple of (line_graph, revid_index, columns_len) where
@@ -43,7 +43,6 @@
     curved, kinked, etc.) and to pick the actual colours for each index.
     """
     
-    graph = repository.get_graph()
     graph_parents = {}
     ghosts = set()
     graph_children = {}

=== modified file 'branchview/treeview.py'
--- branchview/treeview.py	2008-06-28 15:45:39 +0000
+++ branchview/treeview.py	2008-06-29 15:47:30 +0000
@@ -285,7 +285,7 @@
         show_graph = self.graph_column.get_visible()
 
         self.branch.lock_read()
-        (linegraphdata, index, columns_len) = linegraph(self.branch.repository,
+        (linegraphdata, index, columns_len) = linegraph(self.branch.repository.get_graph(),
                                                         (self.start,) , # Sequence of start revisions
                                                         self.maxnum, 
                                                         broken_line_length,

=== modified file 'tests/__init__.py'
--- tests/__init__.py	2007-10-30 21:15:13 +0000
+++ tests/__init__.py	2008-06-29 15:54:40 +0000
@@ -27,6 +27,7 @@
     testmod_names = [
         'test_commit',
         'test_diff',
+        'test_linegraph',
         'test_preferences',
         'test_history',
         ]

=== added file 'tests/test_linegraph.py'
--- tests/test_linegraph.py	1970-01-01 00:00:00 +0000
+++ tests/test_linegraph.py	2008-06-29 15:54:40 +0000
@@ -0,0 +1,45 @@
+# Copyright (C) 2008 Jelmer Vernooij <jelmer@samba.org>
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+"""Test the linegraph functionality."""
+
+import os
+
+import gtk
+
+from bzrlib import (
+	graph,
+    tests,
+    )
+from bzrlib.util import bencode
+
+from bzrlib.plugins.gtk.branchview.linegraph import linegraph
+
+
+class TestLinegraph(tests.TestCase):
+	def get_graph(self, dict):
+		return graph.Graph(graph.DictParentsProvider(dict))
+
+	def test_simple(self):
+		lg = linegraph(self.get_graph({"A": ("B", "C"), "B": ()}), ["A"])
+		self.assertEquals(lg,  
+            ([
+               ['A', (0, 0), [(0, 0, 0)], ['B'], [], (2,)],
+               ['B', (0, 0), [], (), ['A'], (1,)]
+             ],
+             {'A': 0, 'B': 1},
+             1))
+

